@@ -149,7 +149,7 @@ transient_layers = [ 'transient' ]
 # overlays.
 overlay_layers = [ 'overlay' ]
 
-# A list of layers that should be cleared whe we enter a
+# A list of layers that should be cleared when we enter a
 # new context.
 context_clear_layers = [ 'screens' ]
 
@@ -631,6 +631,39 @@ quit_on_mobile_background = False
 # Should Ren'Py pass the raw joystick (not controller) events.?
 pass_joystick_events = False
 
+# A list of screens that should be shown when the overlay is enabled.
+overlay_screens = [ ]
+
+# A map from tag to the default layer that tag should be displayed on.
+tag_layer = { }
+
+# The default layer for tags not in in tag_layer.
+default_tag_layer = 'master'
+
+# A map from tag to the default transform that's used for that tag.
+tag_transform = { }
+
+# A map from the tag to the default zorder that's used for that tag.
+tag_zorder = { }
+
+# The width of lines logged with renpy.log.
+log_width = 78
+
+# The size of the rollback side, as a fraction of the screen.
+rollback_side_size = .2
+
+# If dpi_scale is less than this, make it 1.0.
+de_minimus_dpi_scale = 1.0
+
+# How big must dpi_scale be to deal with it on windows?
+if renpy.windows and renpy.windows <= (6, 3):
+    windows_dpi_scale_head = 1.3
+else:
+    windows_dpi_scale_head = 1.0
+
+# Should rollback_side be enabled?
+enable_rollback_side = False
+
 del renpy
 del os
 
